yafowil.widget.location
=======================

This is the location widget for `yafowil <http://pypi.python.org/pypi/yafowil>`_,
based on `Leaflet http://leafletjs.org`_

- `Documentation <http://docs.yafowil.info/en/latest/blueprints.html#location>`_

- `DEMO - see it Live <http://demo.yafowil.info/++widget++yafowil.widget.location/index.html>`_


Source Code
===========

The sources are in a GIT DVCS with its main branches at
`github <http://github.com/bluedynamics/yafowil.widget.location>`_.

We'd be happy to see many forks and pull-requests to make YAFOWIL even better.


Contributors
============

- Robert Niederreiter <rnix [at] squarewave [dot] at>
